@@ -1,4 +1,4 @@
-"loglikltm" <-
+`loglikltm` <-
 function (betas, constraint) {
     betas <- betas.ltm(betas, constraint, p, q.)
     pr <- probs(Z %*% t(betas))
